﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;

namespace RuutPindala
{
    internal class RuutPindala
    {
        private class Point
        {
            public int X, Y;

            public override string ToString()
            {
                return string.Format("({0};{1})", X, Y);
            }
        }

        private static void Main(string[] args)
        {
            if (args.Length > 0)
            {
                Stopwatch w = new Stopwatch();
                for (int i = 0; i < int.Parse(args[0]); i++)
                {
                    w.Restart();
                    Solve("input" + i + ".txt", "output" + i + ".txt");
                    w.Stop();
                    Console.WriteLine(i + " " + w.Elapsed);
                }
            }
            else
            {
                Solve("pindpsis.txt", "pindpval.txt");
            }
        }

        private static void Solve(string input, string output)
        {
            string s;
            using (StreamReader reader = new StreamReader(input))
            {
                reader.ReadLine();
                s = reader.ReadLine();
            }

            Debug.Assert(s != null, "s != null");
            Point[] points = new Point[s.Length];
            int x = 0;
            int y = 0;
            for (int i = 0; i < s.Length; i++)
            {
                switch (s[i])
                {
                    case 'S':
                        y--;
                        break;
                    case 'N':
                        y++;
                        break;
                    case 'W':
                        x--;
                        break;
                    case 'E':
                        x++;
                        break;
                }

                points[i] = new Point { X = x, Y = y };
            }

            if ((points[points.Length - 1].X != 0) || (points[points.Length - 1].Y != 0))
            {
                throw new InvalidOperationException("Appi-appi");
            }

            using (StreamWriter writer = new StreamWriter(output))
            {
                writer.WriteLine(GetArea(points));
            }
        }

        private static long GetArea(IList<Point> v)
        {
            int n = v.Count;
            long area = 0;

            for (int i = 0; i < n; i++)
            {
                area += v[i].X * (v[(i + 1) % n].Y - v[(i + n - 1) % n].Y);
            }
            return Math.Abs(area) / 2;
        }
    }
}