﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;

namespace RuutVang
{
    internal class RuutVang
    {
        private static int[,] _board;
        private static int _x;
        private static int _y;

        private class Point
        {
            public int X, Y;

            public override string ToString()
            {
                return string.Format("({0};{1})", X, Y);
            }
        }

        private static void Main(string[] args)
        {
            if (args.Length > 0)
            {
                Stopwatch w = new Stopwatch();
                for (int i = 0; i < int.Parse(args[0]); i++)
                {
                    w.Restart();
                    Solve("input" + i + ".txt", "output" + i + ".txt");
                    w.Stop();
                    Console.WriteLine(i + " " + w.Elapsed);
                }
            }
            else
            {
                Solve("vangsis.txt", "vangval.txt");
            }
        }

        private static void Solve(string input, string output)
        {
            Point guard = new Point();
            Point prisoner = new Point();
            string s;
            using (StreamReader reader = new StreamReader(input))
            {
                reader.ReadLine();
                s = reader.ReadLine();
                int[] c = reader.ReadLine().Split().Select(int.Parse).ToArray();
                prisoner.X = c[0];
                prisoner.Y = c[1];
                c = reader.ReadLine().Split().Select(int.Parse).ToArray();
                guard.X = c[0];
                guard.Y = c[1];
            }

            Debug.Assert(s != null, "s != null");
            List<Point> points = new List<Point>();

            int x = 0;
            int y = 0;
            foreach (char c in s)
            {
                switch (c)
                {
                    case 'N':
                        points.Add(new Point { X = x, Y = y });
                        y++;
                        break;
                    case 'S':
                        y--;
                        points.Add(new Point { X = x, Y = y });
                        break;
                    case 'W':
                        x--;
                        break;
                    case 'E':
                        x++;
                        break;
                }
            }

            points.Sort((p1, p2) => p1.Y == p2.Y ? p1.X - p2.X : p1.Y - p2.Y);

            int minX = points.Min(p => p.X);
            int maxX = points.Max(p => p.X);
            int minY = points.Min(p => p.Y);
            int maxY = points.Max(p => p.Y);

            _y = maxY - minY + 1;
            _x = maxX - minX;
            _board = new int[_x, _y];

            foreach (Point point in points)
            {
                point.X -= minX;
                point.Y -= minY;
            }
            points.Add(new Point { X = _x, Y = _y - 1 });

            prisoner.X -= minX;
            prisoner.Y -= minY;
            guard.X -= minX;
            guard.Y -= minY;

            Queue<int> pSquares = new Queue<int>();

            Queue<int> gSquares = new Queue<int>();

            int curX = 0;
            int curY = 0;
            bool wall = true;
            foreach (Point p in points)
            {
                for (int i = _x * curY + curX; i < _x * p.Y + p.X; i++)
                {
                    if (wall)
                    {
                        _board[i % _x, i / _x] = 4;
                    }
                }
                curX = p.X;
                curY = p.Y;
                wall = !wall;
            }

            //Random r = new Random();
            //do
            //{
            //    x = r.Next(_x);
            //    y = r.Next(_y);
            //} while (_board[x, y] != 0);
            //prisoner.X = x;
            //prisoner.Y = y;
            //_board[prisoner.X, prisoner.Y] = 1;
            //do
            //{
            //    x = r.Next(_x);
            //    y = r.Next(_y);
            //} while (_board[x, y] != 0);
            //guard.X = x;
            //guard.Y = y;
            //using (StreamWriter writer = new StreamWriter(input))
            //{
            //    writer.WriteLine(s.Length);
            //    writer.WriteLine(s);
            //    writer.WriteLine("{0} {1}", prisoner.X + minX, prisoner.Y + minY);
            //    writer.WriteLine("{0} {1}", guard.X + minX, guard.Y + minY);
            //}
            //_board[guard.X, guard.Y] = 2;

            //if (_x < 100)
            //{
            //    WriteBoard();
            //}

            //return;

            _board[prisoner.X, prisoner.Y] = 1;
            _board[guard.X, guard.Y] = 2;

            pSquares.Enqueue(_x * prisoner.Y + prisoner.X);
            gSquares.Enqueue(_x * guard.Y + guard.X);

            int pc = 1;

            int count = 0;
            while (pc > 0)
            {
                pc += MakeMove(pSquares, 1);
                pc -= MakeMove(gSquares, 2);
                pc -= MakeMove(gSquares, 2);
                count++;
            }

            using (StreamWriter writer = new StreamWriter(output))
            {
                writer.WriteLine(count);
            }
        }

        private static int MakeMove(Queue<int> q, int val)
        {
            int[] dx = { -1, 0, 0, 1 };
            int[] dy = { 0, -1, 1, 0 };

            int res = 0;
            int pe = q.Count;
            for (int i = 0; i < pe; i++)
            {
                int n = q.Dequeue();
                int px = n % _x;
                int py = n / _x;

                for (int j = 0; j < 4; j++)
                {
                    int npx = px + dx[j];
                    int npy = py + dy[j];
                    if (npx >= 0 && npx < _x && npy >= 0 && npy < _y)
                    {
                        int old = _board[npx, npy];
                        if (old < val)
                        {
                            if (val - old == 1)
                            {
                                res++;
                            }
                            q.Enqueue(npy * _x + npx);
                            _board[npx, npy] = val;
                        }
                    }
                }
            }

            return res;
        }

        private static void WriteBoard()
        {
            for (int i = 0; i < _y; i++)
            {
                for (int j = 0; j < _x; j++)
                {
                    Console.Write(_board[j, i]);
                }
                Console.WriteLine();
            }
        }
    }
}